/*
 Workshop Internet of Things
 Maker Faire Rome 2016
 15-16 ottobre
 STEP 2
 Acquisizione di un ingresso analogico,
 emissione su uscita analogica con messa in scala
 e diagnostica sul canale seriale.
 Il loop di programma acquisisce ripetutamente il valore analogico
 dell'ingresso A0 a cui è collegato un potenziometro.
 Il valore compreso tra 0 e 1023 viene mappato nel range 0/255
 in modo da poter essere inviato ad una uscita analogica (PWM)
 a cui è collegato un LED 
 che si accende in modo proporzionale al valore letto.
 I due valori (originale e scalato) vengono inviati al canale seriale
 Un ritardo di 250 mSec viene inserito per facilitare la visualizzazione.
 
 Hardware:
 * Intel Edison con Edison Kit for Arduino 
 * Grove Starter Kit IoT Edition
 * Grove Rotary Angle sensor (Potenziometro) 
 * Grove LED Socket Kit (Blu)
  
 creato: 05/09/2016
 da Duilio Peroni
 
 http://www.schoolmakerday.it/iot
 Questo codice è di pubblico dominio
 */

//variabili
int valoreAnalogico;
int uscitaAnalogica;

//costanti
//N.B. in configurazione di default solo i pin 3,5,6 e 9
//possono essere uscite analogiche
const int pinAnalogico = 3; //definizione del pin di uscita analogica
const int pinSensore = A0;   //definizione del pin di ingresso analogico

// Funzione setup
//  Inizializza il canale seriale 
//  alla velocità di default (9600 bit/s)
//  e imposta D3 come uscita
void setup() {
  Serial.begin(9600);
  pinMode(pinAnalogico,OUTPUT);
}

// Funzione loop
//  viene ripetutamente letto il valore analogico del canale A0
//  viene scalato da 0/1023 a 0/255 per generare il valore di uscita
//  viene inviato all'uscita 
//  (LED blu acceso in modo proporzionale alla rotazione del potenziometro)
//  ed il risultato viene inviato sul canale seriale per diagnostica
//  un ritardo di 250 mSec facilita la lettura del monitor
void loop() {
  valoreAnalogico=analogRead(pinSensore);             //legge ingresso analogico  
  uscitaAnalogica=map(valoreAnalogico,0,1023,0,255);  //mette in scala
  analogWrite(pinAnalogico,uscitaAnalogica);          //scrive uscita analogica 
  Serial.print(valoreAnalogico);                      //invia per diagnostica
  Serial.print(" "); 
  Serial.println(uscitaAnalogica);
  delay(250);                                         //attende 
}
